==> order-center-domain-3.0.0-CLOUD-DEV-20250401.073106-168-sources.jar: com/tydic/dyc/oc/model/shiporder/sub/UocShipOrderItem.java <==
package com.tydic.dyc.oc.model.shiporder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderItem
 * 说明:发货明细
 * 时间:2022-02-21 19:12
 * 作者:罗有
 **/
@Data
public class UocShipOrderItem implements Serializable {
	private static final long serialVersionUID =  4281205375775446166L;


	@DocField(value = "发货明细id")
	private Long shipOrderItemId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "执行明细id")
	private Long implOrderItemId;

	@DocField(value = "销售明细id")
	private Long saleOrderItemId;


	@DocField(value = "发货单id")
	private Long shipOrderId;

	@DocField(value = "明细状态")
	private String shipItemState;

	@DocField(value = "计量单位")
	private String unitName;

	@DocField(value = "发货数量")
	private BigDecimal sendCount;

	@DocField(value = "到货数量             供应商到货登记时预留字段")
	private BigDecimal arriveCount;

	@DocField(value = "拒收数量")
	private BigDecimal refuseCount;

	@DocField(value = "退货数量")
	private BigDecimal returnCount;

	@DocField(value = "验收数量")
	private BigDecimal inspCount;

	@DocField(value = "异常变更在途数量，表示异常供应商确认之前的记录数量")
	private BigDecimal chngingCount;

	@DocField(value = "售后在途数量")
	private BigDecimal afterServingCount;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "明细拓展")
	private List<UocShipItemMap> itemExtParallelBoList;

	@DocField(value = "发货单明细ID List")
	private List<Long> shipOrderItemIdList;

	@DocField(value = "超验数量")
	private BigDecimal inspSuperCount;


	@DocField(value = "租户id")
	private Long sysTenantId;

	@DocField(value = "租户名称")
	private String sysTenantName;
}

==> order-center-domain-3.1.0-CLOUD-DEV-20230626.005721-59-sources.jar: com/tydic/dyc/oc/model/shiporder/sub/UocShipOrderItem.java <==
package com.tydic.dyc.oc.model.shiporder.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderItem
 * 说明:发货明细
 * 时间:2022-02-21 19:12
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocShipOrderItem implements Serializable {
	private static final long serialVersionUID =  4281205375775446166L;


	@DocField(value = "发货明细id")
	private Long shipOrderItemId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "执行明细id")
	private Long implOrderItemId;

	@DocField(value = "销售明细id")
	private Long saleOrderItemId;


	@DocField(value = "发货单id")
	private Long shipOrderId;

	@DocField(value = "明细状态")
	private String shipItemState;

	@DocField(value = "计量单位")
	private String unitName;

	@DocField(value = "发货数量")
	private BigDecimal sendCount;

	@DocField(value = "到货数量             供应商到货登记时预留字段")
	private BigDecimal arriveCount;

	@DocField(value = "拒收数量")
	private BigDecimal refuseCount;

	@DocField(value = "退货数量")
	private BigDecimal returnCount;

	@DocField(value = "验收数量")
	private BigDecimal inspCount;

	@DocField(value = "异常变更在途数量，表示异常供应商确认之前的记录数量")
	private BigDecimal chngingCount;

	@DocField(value = "售后在途数量")
	private BigDecimal afterServingCount;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "明细拓展")
	private List<UocShipItemMap> itemExtParallelBoList;

	@DocField(value = "发货单明细ID List")
	private List<Long> shipOrderItemIdList;

	@DocField(value = "超验数量")
	private BigDecimal inspSuperCount;
}
